OrderedTimeline mixin

Use this mixin on a PubSub, if you need exact global unique temporal order guaranteed

Superclass constraints

Properties

ephemeral bool
Do not mess with this
getter/setter pairinherited
fetchStrategy FetchStrategy
Do not mess with this
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduled bool
getter/setter pair
scheduledEvents List<LocalityEvent>
getter/setter pair
timeline Timeline
getter/setter pairinherited
waitingMessages Map<int, WaitingMessage>
getter/setter pairinherited

Methods

getLocalizedTopic() String
Return the global topic of the PubSub. All observers of the same topic will receive the same events.
inherited
getTopic() String
inherited
getWaitingMessages() List<WaitingMessage>
inherited
isNimbus() bool
inherited
isTopicSharedAcrossApps() bool
Overwrite this, if you want to share this topic across many apps. Otherwise, the topic will be visible only in the context of the app.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onReceive(LocalityEvent localityEvent) → void
React to events being thrown. Use switch case on the localityEvent.event
override
onReceiveInOrder(List<LocalityEvent> event) → dynamic
onReorder(LocalityEvent fromEvent, LocalityEvent toEvent) → dynamic
send(String event, Map<String, dynamic> payload) WaitingMessage
Send an event with a payload to this PubSub. PubSub ensures each event will be received in onReceive exactly once. This will return a waiting message that gets resolved as soon as it has been received on the server. Use .addListener to wait for messages to resolve.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited