Supervisor class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
listen(String topic, OnChannelConnected onChannelConnected, {bool messagingTopic = true})
→ void
-
Register this topic as a topic to be listenes to. Will call onChannelConnected method once the topic has been connected.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
start()
→ void
-
Start the supervisor. Do not use directly.
-
toString()
→ String
-
A string representation of this object.
inherited